@@ -1,5 +1,5 @@
 package Bot::Cobalt::Plugin::Games::Roulette;
-$Bot::Cobalt::Plugin::Games::Roulette::VERSION = '0.021001';
+$Bot::Cobalt::Plugin::Games::Roulette::VERSION = '0.021002';
 use v5.10;
 use strict; use warnings;
 
@@ -46,7 +46,7 @@ sub execute {
 
 
   --$self->{$context}->{$nick}->{Loaded};
-  return 'Click . . .'
+  return "${nick}: Click . . ."
 }
 
 sub expire {
